'use strict';

exports.__esModule = true;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _PlotArea = require('./PlotArea');

var _PlotArea2 = _interopRequireDefault(_PlotArea);

var _Axis = require('./Axis');

var _Axis2 = _interopRequireDefault(_Axis);

var _ToolTip = require('./ToolTip');

var _ToolTip2 = _interopRequireDefault(_ToolTip);

var _Dots = require('../Chart/Dots');

var _Dots2 = _interopRequireDefault(_Dots);

var _ChartOverlay = require('../Chart/ChartOverlay');

var _ChartOverlay2 = _interopRequireDefault(_ChartOverlay);

var _utils = require('../Chart/utils');

var ChartUtils = _interopRequireWildcard(_utils);

require('../../../styles/components/area-chart.css');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var d3 = (0, _assign2['default'])({}, require('d3-shape'), require('d3-format'), require('d3-axis'));

var AreaChart = function (_React$Component) {
  (0, _inherits3['default'])(AreaChart, _React$Component);

  function AreaChart(props) {
    (0, _classCallCheck3['default'])(this, AreaChart);

    var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

    _this.state = {
      tooltip: {
        display: false,
        data: { key: '', value: '' },
        pos: { x: '', y: '' }
      }
    };
    _this.showToolTip = _this.showToolTip.bind(_this);
    _this.hideToolTip = _this.hideToolTip.bind(_this);
    _this.mouseMove = _this.mouseMove.bind(_this);
    _this.renderToolTip = _this.renderToolTip.bind(_this);
    return _this;
  }

  AreaChart.prototype.mouseMove = function mouseMove(toolTipData, toolTipPos) {
    this.setState({
      tooltip: {
        display: true,
        data: toolTipData,
        pos: toolTipPos
      }
    });
  };

  AreaChart.prototype.showToolTip = function showToolTip(e) {
    this.setState({
      tooltip: {
        display: true,
        data: {
          key: e.target.getAttribute('data-key'),
          value: e.target.getAttribute('data-value')
        },
        pos: {
          x: e.target.getAttribute('cx'),
          y: e.target.getAttribute('cy')
        }
      }
    });
  };

  AreaChart.prototype.hideToolTip = function hideToolTip() {
    this.setState({
      tooltip: {
        display: false,
        data: {}
      }
    });
  };

  AreaChart.prototype.renderToolTip = function renderToolTip() {
    var _this2 = this;

    if (this.props.tooltipVisible) {
      return _react2['default'].createElement(
        _ToolTip2['default'],
        { tooltip: this.state.tooltip },
        this.props.tooltipContentType.map(function (type, index) {
          if (type === 'up') {
            return _react2['default'].createElement(
              'g',
              { key: index },
              _react2['default'].createElement('polygon', { fill: '#A676B2', points: '38,-3 34,1 42,1' }),
              _react2['default'].createElement(
                'text',
                null,
                _react2['default'].createElement(
                  'tspan',
                  { className: type, is: true, 'text-anchor': 'middle', x: '58px', y: '2px', 'font-size': '11px', fill: '#A676B2' },
                  _this2.state.tooltip.data[type]
                )
              )
            );
          } else if (type === 'down') {
            return _react2['default'].createElement(
              'g',
              { key: index },
              _react2['default'].createElement('polygon', { fill: '#A676B2', points: '38,17 34,13 42,13' }),
              _react2['default'].createElement(
                'text',
                null,
                _react2['default'].createElement(
                  'tspan',
                  { className: type, is: true, 'text-anchor': 'middle', x: '60px', y: '18px', 'font-size': '11px', fill: '#A676B2' },
                  _this2.state.tooltip.data[type]
                )
              )
            );
          }
          return _react2['default'].createElement(
            'g',
            { key: index },
            _react2['default'].createElement(
              'text',
              null,
              _react2['default'].createElement(
                'tspan',
                { className: type, is: true, 'text-anchor': 'middle', x: '-20px', y: '15px', 'font-size': '28px', fill: '#A676B2' },
                _this2.state.tooltip.data[type]
              )
            )
          );
        })
      );
    }
    return '';
  };

  AreaChart.prototype.render = function render() {
    var _props = this.props,
        dotVisible = _props.dotVisible,
        height = _props.height,
        hideAxisX = _props.hideAxisX,
        hideAxisY = _props.hideAxisY,
        tooltipVisible = _props.tooltipVisible,
        width = _props.width,
        xDataType = _props.xDataType,
        yBuffer = _props.yBuffer;

    var margin = { top: 5, right: 50, bottom: 20, left: 50 };
    var innerWidth = width - (margin.left + margin.right);
    var innerHeight = height - (margin.top + margin.bottom);
    var data = this.props.data;
    var xAxis = null;
    var xScale = null;
    var xScaleAxis = null;

    if (this.props.xDataType === 'date') {
      var parseDate = d3.timeParse('%m-%d-%Y %H:%M:%S');
      data.forEach(function (d) {
        d.x = parseDate(d.x);
      });
      xScale = ChartUtils.xScaleTime(data, width);
      xScaleAxis = ChartUtils.xScaleTime(data, width - 40);
      xAxis = d3.axisBottom().scale(xScaleAxis).tickValues(data.map(function (d) {
        return d.x;
      })).ticks(5).tickFormat(d3.timeFormat('%a'));
    } else {
      xScale = ChartUtils.xScaleLinear(data, width);
      xScaleAxis = ChartUtils.xScaleLinear(data, width - 40);
      xAxis = d3.axisBottom().scale(xScaleAxis).tickValues(data.map(function (d) {
        return d.x;
      })).ticks(5);
    }

    var yScale = ChartUtils.yScaleLinear(data, innerHeight, yBuffer);

    var yAxis = d3.axisLeft().scale(yScale).ticks(5);

    return _react2['default'].createElement(
      'div',
      { className: 'area__chart__container' },
      _react2['default'].createElement(
        'svg',
        { width: width, height: innerHeight },
        _react2['default'].createElement(
          'g',
          { transform: 'translate(2, 4)' },
          _react2['default'].createElement(_PlotArea2['default'], (0, _extends3['default'])({}, this.props, {
            data: data,
            xScale: xScale,
            yScale: yScale
          })),
          hideAxisX ? '' : _react2['default'].createElement(_Axis2['default'], { height: innerHeight, width: innerWidth - 10, axis: xAxis, axisType: 'x', orientation: 'bottom' }),
          hideAxisY ? '' : _react2['default'].createElement(_Axis2['default'], { height: innerHeight, axis: yAxis, axisType: 'y', orientation: 'left' }),
          this.renderToolTip(),
          dotVisible ? _react2['default'].createElement(_Dots2['default'], {
            data: data,
            showToolTip: this.showToolTip,
            hideToolTip: this.hideToolTip,
            xDataType: xDataType,
            xScale: xScale,
            yScale: yScale
          }) : '',
          tooltipVisible ? _react2['default'].createElement(_ChartOverlay2['default'], {
            data: data,
            height: innerHeight,
            hideToolTip: this.hideToolTip,
            mouseMove: this.mouseMove,
            width: width,
            xDataType: xDataType,
            xScale: xScale,
            yScale: yScale
          }) : ''
        )
      )
    );
  };

  return AreaChart;
}(_react2['default'].Component);

AreaChart.propTypes = {
  data: _react2['default'].PropTypes.array.isRequired,
  dotVisible: _react2['default'].PropTypes.bool,
  height: _react2['default'].PropTypes.number,
  hideAxisX: _react2['default'].PropTypes.bool,
  hideAxisY: _react2['default'].PropTypes.bool,
  tooltipContentType: _react2['default'].PropTypes.array.isRequired,
  tooltipVisible: _react2['default'].PropTypes.bool,
  width: _react2['default'].PropTypes.number,
  xDataType: _react2['default'].PropTypes.string.isRequired,
  yBuffer: _react2['default'].PropTypes.number.isRequired,
  tooltipWidth: _react2['default'].PropTypes.number,
  tooltipHeight: _react2['default'].PropTypes.number
};

AreaChart.defaultProps = {
  color: '#00A4D8',
  dotVisible: true,
  height: 150,
  padding: 20,
  tooltipContentType: ['x', 'y'],
  tooltipVisible: true,
  tooltipWidth: 150,
  tooltipHeight: 40,
  width: 500,
  xDataType: 'number',
  yBuffer: 0
};

exports['default'] = AreaChart;
module.exports = exports['default'];
//# sourceMappingURL=AreaChart.js.map